@@ -1,5 +1,5 @@
 /* Create descriptor for assembling.
-   Copyright (C) 2002 Red Hat, Inc.
+   Copyright (C) 2002, 2016 Red Hat, Inc.
    This file is part of elfutils.
    Written by Ulrich Drepper <drepper@redhat.com>, 2002.
 
@@ -58,8 +58,8 @@ prepare_text_output (AsmCtx_t *result)
 	  free (result);
 	  result = NULL;
 	}
-
-      __fsetlocking (result->out.file, FSETLOCKING_BYCALLER);
+      else
+	__fsetlocking (result->out.file, FSETLOCKING_BYCALLER);
     }
 
   return result;
@@ -98,7 +98,7 @@ prepare_binary_output (AsmCtx_t *result, Ebl *ebl)
   /* Set the ELF version.  */
   ehdr->e_version = EV_CURRENT;
 
-  /* Use the machine, class, and endianess values from the Ebl descriptor.  */
+  /* Use the machine, class, and endianness values from the Ebl descriptor.  */
   ehdr->e_machine = ebl_get_elfmachine (ebl);
   ehdr->e_ident[EI_CLASS] = class;
   ehdr->e_ident[EI_DATA] = ebl_get_elfdata (ebl);
@@ -115,8 +115,8 @@ prepare_binary_output (AsmCtx_t *result, Ebl *ebl)
   asm_symbol_tab_init (&result->symbol_tab, 67);
   result->nsymbol_tab = 0;
   /* And the string tables.  */
-  result->section_strtab = ebl_strtabinit (true);
-  result->symbol_strtab = ebl_strtabinit (true);
+  result->section_strtab = dwelf_strtab_init (true);
+  result->symbol_strtab = dwelf_strtab_init (true);
 
   /* We have no section groups so far.  */
   result->groups = NULL;
