@@ -88,6 +88,13 @@ get_shnum (void *map_address, unsigned char *e_ident, int fildes,
   } ehdr_mem;
   bool is32 = e_ident[EI_CLASS] == ELFCLASS32;
 
+  if ((is32 && maxsize < sizeof (Elf32_Ehdr))
+      || (!is32 && maxsize < sizeof (Elf64_Ehdr)))
+    {
+       __libelf_seterrno (ELF_E_INVALID_ELF);
+      return (size_t) -1l;
+    }
+
   /* Make the ELF header available.  */
   if (e_ident[EI_DATA] == MY_ELFDATA
       && (ALLOW_UNALIGNED
@@ -1040,7 +1047,7 @@ dup_elf (int fildes, Elf_Cmd cmd, Elf *ref)
     }
 
   /* This is an archive.  We must create a descriptor for the archive
-     member the internal pointer of the archive file desriptor is
+     member the internal pointer of the archive file descriptor is
      pointing to.  First read the header of the next member if this
      has not happened already.  */
   if (ref->state.ar.elf_ar_hdr.ar_name == NULL
@@ -1064,7 +1071,7 @@ dup_elf (int fildes, Elf_Cmd cmd, Elf *ref)
 }
 
 
-/* Return desriptor for empty file ready for writing.  */
+/* Return descriptor for empty file ready for writing.  */
 static struct Elf *
 write_file (int fd, Elf_Cmd cmd)
 {
