@@ -18,4 +18,4 @@
 . $srcdir/test-subr.sh
 
 # Just makes sure readelf doesn't crash
-testrun_on_self_quiet ../src/readelf -a -w
+testrun_on_self_quiet ${abs_top_builddir}/src/readelf -a -w
